@@ -30,12 +30,12 @@ sub query_form {
         my @query;
         while (my($key,$vals) = splice(@_, 0, 2)) {
             $key = '' unless defined $key;
-	    $key =~ s/([;\/?:@&=+,\$%])/$URI::Escape::escapes{$1}/g;
+	    $key =~ s/([;\/?:@&=+,\$\[\]%])/$URI::Escape::escapes{$1}/g;
 	    $key =~ s/ /+/g;
 	    $vals = [ref($vals) ? @$vals : $vals];
             for my $val (@$vals) {
                 $val = '' unless defined $val;
-		$val =~ s/([;\/?:@&=+,\$%])/$URI::Escape::escapes{$1}/g;
+		$val =~ s/([;\/?:@&=+,\$\[\]%])/$URI::Escape::escapes{$1}/g;
                 $val =~ s/ /+/g;
                 push(@query, "$key=$val");
             }
@@ -56,7 +56,7 @@ sub query_keywords
     if (@_) {
         # Try to set query string
 	my @copy = @_;
-	for (@copy) { s/([;\/?:@&=+,\$%])/$URI::Escape::escapes{$1}/g; }
+	for (@copy) { s/([;\/?:@&=+,\$\[\]%])/$URI::Escape::escapes{$1}/g; }
 	$self->query(join('+', @copy));
     }
     return if !defined($old) || !defined(wantarray);
